# Request time series data
# 
# Author: Antonio Rodriges

queryTimeSeries <- function(
		wikienceConnection, 
		datasetName, 
		timeStart, timeEnd,
		latitudeSouth, longitudeWest, 
		latitudeNorth, longitudeEast) {
	
	.jcall(
		wikienceConnection, 
		"V", 
		"queryTimeSeries", 
		datasetName, 
		timeStart, timeEnd,
		latitudeSouth, longitudeWest, 
		latitudeNorth, longitudeEast ) 
}

getTimeSeriesPointCount <- function(wikienceConnection) {
	count <- .jcall(
			wikienceConnection, 
			"I", 
			"getTimeSeriesPointCount")
	
	return (count)
}
		
getTimeSeries <- function(wikienceConnection, pointNumber) {
	vector <- .jcall(
			wikienceConnection, 
			"[D", 
			"getTimeSeries", 
			as.integer(pointNumber))
	
	timeStart <- vector[1]
	timeStep <- vector[2]
	type <- vector[3]
	
	data <- vector[-c(1,2,3)]
	
	data[data <= -3.402823e+38] <- NA;
	
	if(type == 0){
		#datesUnix <- seq(timeStart, length = length(data), by=timeStep)
		posixTime <- .jcall(w, "[S", "posixTime", timeStart, length(data), timeStep)
		#posixTime <- sapply(datesUnix, convertTimeToString)
		#posixTime <- as.POSIXct(strptime(posixTime, format = "%Y-%m-%d %H:%M:%S","GMT"))
		posixTime <- as.POSIXct(posixTime, tz="GMT")
	} else {
		datesUnix <- seq(
				as.Date(convertTimeToString(timeStart)), 
				length = length(data), 
				by = "1 mon")
		
		posixTime <- as.character(datesUnix)
		posixTime <- as.POSIXct(strptime(posixTime, format = "%Y-%m-%d","GMT"))
	}
	
	dataFrame <- data.frame(date=posixTime, value=data)
	
	return(dataFrame)
}

getTimeSeriesPointsLatsLons <- function(wikienceConnection){
	vector <- .jcall(wikienceConnection, "[D", "getTimeSeriesPointsLatsLons") 
	matr <- matrix(vector, ncol = 2, byrow = T)
	lats <- matr[, 1]
	lons <- matr[, 2]
	df <- data.frame(lat=lats, lon=lons)
	return(df)
}

## Retrieve all points
getAllTimeSeries <- function (wikienceConnection) {
	result <- getTimeSeriesPointsLatsLons(wikienceConnection)
	
}