# Tools for working with wind speed and direction data
# 
# Author: (c) R.A. Rodriges Zalipynis, rodriges@wikience.org
###############################################################################

# Input: U and V data frames with (date, value)
# Output: data frame (date, ws, wd) - date, wind speed, wind direction
convertUVtoSpeedAndDirection <- function(U, V, doDataCheck = T) {
	
	## Check input data
	if (doDataCheck == T && U$date != V$date) stop("U and V dates do not coinside. Hint: are U & V from diferent points?")
	
	mydata<-list()
	mydata$u<-U$value
	mydata$v<-V$value
	
	mydata <- transform(mydata, wd = as.vector(atan2(-v, -u) * 360 / 2 /pi), ws = (u^2 + v^2)^0.5)
	
	## correct for negative wind directions
	ids <- which(mydata$wd < 0)  ## ids where wd < 0
	mydata$wd[ids] <- mydata$wd[ids] + 360 
	
	## comply with UK met office standards
	mydata$wd <- 360 - mydata$wd + 90
	ids <- which(mydata$wd > 360)
	mydata$wd[ids] <- mydata$wd[ids] - 360
	
	result <- data.frame(date = U$date, ws = mydata$ws, wd = mydata$wd)
	
	return ( result )
}